%global version 0.9.3.git.20230608.120654.3d45a1b
%global min_required_version_django 3.2

Name:           osh
Version:        covscan.0.8.0
Release:        1.20230608121144886344.gitlab.84.packit.integration.660.g44cdc76%{?dist}
License:        GPL-3.0-or-later
Summary:        Static and Dynamic Analysis as a Service
Source:         covscan-covscan.0.8.0.tar.gz
BuildArch:      noarch

BuildRequires:  koji
BuildRequires:  python3-csdiff
BuildRequires:  python3-devel
BuildRequires:  python3-kobo-client
BuildRequires:  python3-kobo-rpmlib
BuildRequires:  python3-psycopg2
BuildRequires:  python3-setuptools
BuildRequires:  systemd-rpm-macros

# make sure that %%{bash_completions_dir} is defined in the buildroot
%{!?bash_completions_dir: %global bash_completions_dir %{_datadir}/bash-completion/completions}

# The following dependencies are not yet available in EPEL-9.  Make it
# possible to build at least functional up2date osh-client for EPEL-9.
%if 0%{?rhel} != 9
BuildRequires:  python3-django >= %{min_required_version_django}
BuildRequires:  python3-kobo-django
BuildRequires:  python3-kobo-hub
BuildRequires:  python3-qpid-proton
%endif

%description
OpenScanHub is a service for static and dynamic analysis.
It consists of central hub, workers and cli client.


%package client
Summary: OpenScanHub CLI client
Requires: koji
Requires: python3-kobo-client >= 0.15.1-100
Requires: %{name}-common = %{version}-%{release}
Obsoletes: python3-%{name}-client < %{version}-%{release}
# This is kept here for backward compatibility with old package name
Provides: covscan-client = %{version}
Obsoletes: covscan-client < %{version}
Conflicts: covscan-client < %{version}

%description client
OpenScanHub CLI client


%package common
Summary: OpenScanHub shared files for client, hub and worker
Obsoletes: covscan-common < %{version}

%description common
OpenScanHub shared files for client, hub and worker.


%package worker
Summary: OpenScanHub worker
Requires: csmock
Requires: koji
Requires: python3-kobo-client
Requires: python3-kobo-rpmlib
Requires: python3-kobo-worker
Requires: %{name}-common = %{version}-%{release}
Requires: osh-worker-conf

Obsoletes: covscan-worker < %{version}

%description worker
OpenScanHub worker

%package hub
Summary: OpenScanHub xml-rpc interface and web application
Requires: boost-python3
Requires: httpd
Requires: mod_auth_gssapi
Requires: mod_ssl
Requires: python3-django >= %{min_required_version_django}
Requires: python3-kobo-client
Requires: python3-kobo-django
Requires: python3-kobo-hub
Requires: python3-kobo-rpmlib
Requires: python3-mod_wsgi
# PostgreSQL adapter for python
Requires: python3-psycopg2
Requires: gzip
# inform ET about progress using UMB (Unified Message Bus)
Requires: python3-qpid-proton
# hub is interacting with brew
Requires: koji
# extract tarballs created by csmock
Requires: xz

Requires: csdiff
Requires: file
Requires: python3-bugzilla
Requires: python3-csdiff
Requires: python3-jira

Requires(post): /usr/bin/pg_isready

Requires: %{name}-common = %{version}-%{release}
Requires: osh-hub-conf

Obsoletes: covscan-hub < %{version}

%description hub
OpenScanHub xml-rpc interface and web application

# define osh-{worker,hub}-conf-devel subpackages
%(for sub in worker hub; do
cat << EOF
%package ${sub}-conf-devel
Summary: OpenScanHub ${sub} devel configuration
Provides: osh-${sub}-conf = %{version}-%{release}
Conflicts: osh-${sub}-conf
%description ${sub}-conf-devel
OpenScanHub ${sub} devel configuration
EOF
done)

%prep
%setup -q -n covscan-covscan.0.8.0

%build

# Add -s to the shebang in osh/client/osh-cli:
# https://docs.fedoraproject.org/en-US/packaging-guidelines/Python/#_shebang_macros
# TODO: Remove this when we migrate to newer Python packaging macros which
# do this automatically.
%py3_shebang_fix osh/client/osh-cli

%if 0%{?rhel} != 9
# collect static files from Django itself
PYTHONPATH=. osh/hub/manage.py collectstatic --noinput
%endif

%py3_build


%install
%py3_install

%if 0%{?rhel} != 9
# install the files collected by `manage.py collectstatic`
cp -a {,%{buildroot}%{python3_sitelib}/}osh/hub/static/
%endif

# Temporarily provide /usr/bin/covscan for backward compatibility
ln -s osh-cli %{buildroot}%{_bindir}/covscan

# create /etc/osh/hub directory
mkdir -p %{buildroot}%{_sysconfdir}/osh/hub

# create /var/lib dirs
mkdir -p %{buildroot}/var/lib/osh/hub/{tasks,upload,worker}

# create log file
mkdir -p %{buildroot}/var/log/osh/hub
touch %{buildroot}/var/log/osh/hub/hub.log

# copy checker_groups.txt
cp -R osh/hub/scripts/checker_groups.txt %{buildroot}%{python3_sitelib}/osh/hub/scripts/

# make manage.py executable
chmod 0755 %{buildroot}%{python3_sitelib}/osh/hub/manage.py

# scripts are needed for setup.py, no longer needed
rm -rf %{buildroot}%{python3_sitelib}/scripts

%files client
%defattr(644,root,root,755)
%attr(755,root,root) %{_bindir}/osh-cli
%{_bindir}/covscan
%attr(644,root,root) %config(noreplace) /etc/osh/client.conf
%{bash_completions_dir}/osh-cli.bash
%{python3_sitelib}/osh/client
%{python3_sitelib}/osh-*-py%{python3_version}.egg-info

%files common
%defattr(644,root,root,755)
%dir %{_sysconfdir}/osh
%{python3_sitelib}/osh/common
%{python3_sitelib}/osh/__init__.py*
%{python3_sitelib}/osh/__pycache__
%dir %{python3_sitelib}/osh
%dir /var/lib/osh

%files worker
%defattr(644,root,root,755)
%{python3_sitelib}/osh/worker
%{_unitdir}/osh-worker.service
%attr(754,root,root) /usr/sbin/osh-worker

%post client
if test -f /etc/covscan/covscan.conf; then
    mv /etc/covscan/covscan.conf /etc/osh/client.conf
fi

%post worker
%systemd_post osh-worker.service

%preun worker
%systemd_preun osh-worker.service

%postun worker
%systemd_postun_with_restart osh-worker.service

%files worker-conf-devel
%attr(640,root,root) %config(noreplace) /etc/osh/worker.conf

%files hub
%defattr(-,root,apache,-)
%{_sbindir}/osh-stats
%{_sysconfdir}/osh/hub
%{python3_sitelib}/osh/hub
%{_unitdir}/osh-stats.*
%exclude %{python3_sitelib}/osh/hub/settings_local.py*
%exclude %{python3_sitelib}/osh/hub/__pycache__/settings_local.*
%dir %attr(775,root,apache) /var/log/osh/hub
%ghost %attr(640,apache,apache) /var/log/osh/hub/hub.log
%attr(775,root,apache) /var/lib/osh/hub
%ghost %attr(640,root,apache) /var/lib/osh/hub/secret_key

%post hub
exec &>> /var/log/osh/hub/post-install-%{name}-%{version}-%{release}.log

# record timestamp
echo -n '>>> '
date -R

set -x
umask 0026

if ! test -e /var/lib/osh/hub/secret_key; then
    # generate Django secret key for a fresh installation
    %{__python3} -c "from django.core.management.utils import get_random_secret_key
print(get_random_secret_key())" > /var/lib/osh/hub/secret_key
    chgrp apache /var/lib/osh/hub/secret_key
fi

# this only takes an effect if PostgreSQL is running and the database exists
pg_isready -h localhost && %{python3_sitelib}/osh/hub/manage.py migrate

%systemd_post osh-stats.service osh-stats.timer

%preun hub
%systemd_preun osh-stats.service osh-stats.timer

%postun hub
%systemd_postun_with_restart osh-stats.service osh-stats.timer

%files hub-conf-devel
%attr(640,root,apache) %config(noreplace) %{python3_sitelib}/osh/hub/settings_local.py
%attr(640,root,apache) %config(noreplace) %{python3_sitelib}/osh/hub/__pycache__/settings_local*.pyc


%changelog
* Thu Jun 08 2023 Siteshwar Vashisht <svashisht@redhat.com> - covscan.0.8.0-1.20230608121144886344.gitlab.84.packit.integration.660.g44cdc76
- Test (Siteshwar Vashisht)
- hub: remove `ScanListSearchForm.extra_query` (Lukáš Zaoral)
- hub: remove redundant query from `ResultsListView.get_queryset` (Lukáš Zaoral)
- hub: implement the listing of overdue scans as a query (Lukáš Zaoral)
- hub: fix `ScanBindingMixin.latest_packages_scans()` (Lukáš Zaoral)
- hub: simplify control flow in `waived_on_time` (Lukáš Zaoral)
- worker: run osh-worker in foreground in the systemd unit (Kamil Dudka)
- worker: remove the covscand unit alias (Kamil Dudka)
- worker: wait for network properly in the systemd unit (Kamil Dudka)
- ci: assert that all tasks finish successfully (Lukáš Zaoral)
- hub: add search filtering for blocked packages in PackageListView (Lukáš Zaoral)
- hub: add search functionality to the PackageListView (Lukáš Zaoral)
- ci: Remove stale files from `/var/lib/osh/hub/` (Siteshwar Vashisht)
- packaging: make sure that %{bash_completions_dir} is defined (Kamil Dudka)
- packaging: require Django 3.2 or newer (Lukáš Zaoral)
- hub: waiving/models: drop primary-key override on JiraBug (Isabella do Amaral)
- hub: use koji profiles instead of hard-coded koji and brew links (Lukáš Zaoral)
- containers: scripts/init-db: check if dump is accessible (Isabella do Amaral)
- containers: scripts/init-db: fix db restore (Isabella do Amaral)
- containers: scripts/init-db: use `-limited` version of the db dump (Isabella do Amaral)
- hub: set `DEFAULT_AUTO_FIELD` to `AutoField` (Lukáš Zaoral)
- hub: enforce that command_arguments field has expected structure (Lukáš Zaoral)
- hub: use Django's native JSONField implementation (Lukáš Zaoral)
- hub: mark scans with interrupted tasks as failed (Lukáš Zaoral)
- hub: use correct logger prefix in settings_local*.py (Lukáš Zaoral)
- hub: use consistent logger naming (Lukáš Zaoral)
- docs: fix typos and formatting issues (Lukáš Zaoral)
- docs: update outdated links (Lukáš Zaoral)
- docs: complete CovScan -> OpenScanHub renaming (Lukáš Zaoral)
- Remove all remaining Python 2 remnants (Lukáš Zaoral)
- packaging: do not include `static` directory into SRPM (Kamil Dudka)
- packaging: drop covscanhub.wsgi symlink no longer needed (Kamil Dudka)
- ci: containers: docs: Use Fedora 37 instead of Fedora 36 (Siteshwar Vashisht)
- hub: Add `fedora-37-x86_64` mock config in fixtures (Siteshwar Vashisht)
- ci: Add lint workflow for GitHub Actions (Siteshwar Vashisht)
- containers: scripts: manage shell flags (Isabella do Amaral)
- containers: scripts/deploy: simplify clean command (Isabella do Amaral)
- containers: scripts/deploy: simplify prepare_deploy (Isabella do Amaral)
- containers: scripts: prefer arrays for command expansions (Isabella do Amaral)
- containers: deploy: drop podman* version tests (Isabella do Amaral)
- containers: scripts/init-db: drop --deploy flag (Isabella do Amaral)
- containers: scripts: drop wait_for_db function (Isabella do Amaral)
- containers: prefer more general commands (Isabella do Amaral)
- containers: compose: set project name (Isabella do Amaral)
- compose: rename docker-compose.yml to compose.yaml (Isabella do Amaral)
- hub: Make e-mail address for notifications configurable (Siteshwar Vashisht)
- packaging: bump release to 0.9.3 to distribute latest osh-client (Kamil Dudka)
- Update author e-mail to `openscanhub-devel` Google group (Siteshwar Vashisht)
- Fix linter warnings (Siteshwar Vashisht)
- Add SPDX headers inside all the scripts (Siteshwar Vashisht)
- Add `GPL-3.0-or-later` license in the spec file (Siteshwar Vashisht)
- Add GPLv3 license file (Siteshwar Vashisht)
- hub: add a 'New Scan' entry to the menu navigation (Lukáš Zaoral)
- hub: limit the scan submission form to authenticated users (Lukáš Zaoral)
- hub: make the comment field in scan submission form optional (Lukáš Zaoral)
- hub: allow koji builds in the scan submission form (Lukáš Zaoral)
- hub: revive the scan submission form (Lukáš Zaoral)
- hub: create a template for error 403 (Lukáš Zaoral)
- hub: remove Python 2 remnants (Lukáš Zaoral)
- hub: list package blocked status in packages views (Lukáš Zaoral)
- packaging: use Django 3 by default (Lukáš Zaoral)
- ci: always refresh repository metadata in the COPR job (Lukáš Zaoral)
- docs: update managing_database.md (Lukáš Zaoral)
- docs: update ERD snapshot of the database (Lukáš Zaoral)
- hub: remove outdated ERD diagram (Lukáš Zaoral)
- hub: remove code in `scan/task_urls.py` duplicated from kobo (Lukáš Zaoral)
- client: fix traceback with older configuration files (Lukáš Zaoral)
- hub: Rename (or remove) several references of `Covscan` (Siteshwar Vashisht)
- hub: Remove references to Coverity and internal links (Siteshwar Vashisht)
- hub: Add a directory to allow overriding default templates (Siteshwar Vashisht)
- packaging: Rename `covscan` to `osh` in spec file (Siteshwar Vashisht)
- hub: Use `OpenScanHub` name in `UMB_TOPIC_PREFIX` (Siteshwar Vashisht)
- hub: add forgotten migration for scan.Package sorting (Kamil Dudka)
- hub: try to correctly guess the package name from file upload (Lukáš Zaoral)
- hub: limit the computed priority to natural numbers (Lukáš Zaoral)
- client: --priority must be non-negative (Lukáš Zaoral)
- hub: fix rendering of waivers for scans without release tags (Lukáš Zaoral)
- hub: remove BrewException (Lukáš Zaoral)
- hub: replace check_brew_build with check_build (Lukáš Zaoral)
- hub: remove create_base_diff_task function (Lukáš Zaoral)
- hub: remove Python 2 remnants in scan/forms.py (Lukáš Zaoral)
- hub: revert the client API to the original state (Lukáš Zaoral)
- hub: fix overlapping of base and regular scans in packages view (Lukáš Zaoral)
- hub: add link to the waiver for base scans in the packages view (Lukáš Zaoral)
- hub: properly display unsuccessful scans in the packages view (Lukáš Zaoral)
- hub: omit unsuccessful initial scans from the packages view (Lukáš Zaoral)
- hub: always select newest scan for given base NVR in packages view (Lukáš Zaoral)
- hub: show releases in the ascending order in the packages view (Lukáš Zaoral)
- hub: do not list Null releases in packages view (Lukáš Zaoral)
- hub: waiving: source bz and jira links from settings (Isabella Basso do Amaral)
- client: execute python3 through env in osh-cli (Lukáš Zaoral)
- hub: remove duplicate function defintion in `hub/stattypes.py` (Lukáš Zaoral)
- hub: define sorting order for scan.Package (Pavel Simovec)
- hub: increase maximum length of ETMapping comments (Lukáš Zaoral)
- hub: de-duplicate XML-RPC methods for client task creation (Lukáš Zaoral)
- hub: pass all task parameters in the options dictionary (Lukáš Zaoral)
- hub: make ClientDiffScanScheduler a subclass of ClientScanScheduler (Lukáš Zaoral)
- hub: remove handling of removed options in the client (Lukáš Zaoral)
- hub: remove kwargs from ClientScanScheduler's __init__ (Lukáš Zaoral)
- hub: add a systemd service and timer for osh-stats (Lukáš Zaoral)
- packaging: install osh-stats to %{_sbindir} (Lukáš Zaoral)
- hub: rename stats_updater script to osh-stats (Lukáš Zaoral)
- ci: add stats_updater.py test (Lukáš Zaoral)
- hub: account for Results without the scanning_time attribute (Lukáš Zaoral)
- hub: simplify control flow in stats/service (Lukáš Zaoral)
- hub: properly compute number elapsed minutes (Lukáš Zaoral)
- hub: create StatType entries dynamically from the stat functions metadata (Lukáš Zaoral)
- hub: improve logging messages during stats updating (Lukáš Zaoral)
- hub: add newlines to stats/service to improve readability (Lukáš Zaoral)
- hub: use inspect to get functions from a module at runtime (Lukáš Zaoral)
- hub: save all statistic function metadata using @stat_function (Lukáš Zaoral)
- hub: simplify display_values in stats/service.py (Lukáš Zaoral)
- hub: use absolute imports in stats/service.py (Lukáš Zaoral)
- hub: remove Python 2 remnants (Lukáš Zaoral)
- hub: remove outdated and unused JavaScript files from media/js (Lukáš Zaoral)
- hub: use Plotly.js for chart plotting (Lukáš Zaoral)
- hub: initialize dict from a dict literal in stats/views (Lukáš Zaoral)
- hub: use a slice operator to limit a query (Lukáš Zaoral)
- hub: use `application/json` content type for JSON (Lukáš Zaoral)
- hub: encode strings passed to HttpResponse (Lukáš Zaoral)
- hub: deduplicate {release,}_stats_detail_graph (Lukáš Zaoral)
- hub: remove Python 2 remnants (Lukáš Zaoral)
- common: remove unused tasks.py (Lukáš Zaoral)
- packaging: bump release to 0.9.2 to distribute newer osh-cli (Lukáš Zaoral)
- client: revert shebang to use absolute path to python3 (Lukáš Zaoral)
- hub: waiving: fix jira API integration (Isabella Basso do Amaral)
- client: do not hard-code links to Brew or Fedora Koji (Lukáš Zaoral)
- hub: rename 'cs_xmlrpc' to 'osh_xmlrpc' (Lukáš Zaoral)
- hub: remove Python 2 remnants (Lukáš Zaoral)
- hub: remove cs_xmlrpc/test.py (Lukáš Zaoral)
- hub: remove cli_short_command ClientAnalyzer field (Lukáš Zaoral)
- client: remove handling of removed options (Lukáš Zaoral)
- hub: raise a RuntimeError when errata task creation fails (Lukáš Zaoral)
- hub: unify output format in create_scan_cmd (Lukáš Zaoral)
- hub: fix invalid URL example in osh-xmlrpc-client (Lukáš Zaoral)
- hub: use properly formatted tracebacks in osh-xmlrpc-client (Lukáš Zaoral)
- hub: move subparsers variable in osh-xmlrpc-client (Lukáš Zaoral)
- hub: remove redundant operator % calls in osh-xmlrpc-client (Lukáš Zaoral)
- hub: pass arguments directly in osh-xmlrpc-client (Lukáš Zaoral)
- hub: simplify control flow in osh-xmlrpc-client (Lukáš Zaoral)
- hub: remove redundant kwargs for 'hub' parameter (Lukáš Zaoral)
- hub: remove redundant 'hub' variable in osh-xmlrpc-client (Lukáš Zaoral)
- hub: recommend dnf instead of yum in osh-xmlrpc-client (Lukáš Zaoral)
- hub: remove Python 2 remnants (Lukáš Zaoral)
- hub: execute python3 through env in osh-xmlrpc-client (Lukáš Zaoral)
- hub: remove '2' suffix from errata related functions (Lukáš Zaoral)
- hub: replace all usages of return_or_raise with get_or_fail (Lukáš Zaoral)
- hub: remove dead code in the errata module (Lukáš Zaoral)
- hub: remove Python 2 remnants (Lukáš Zaoral)
- hub: remove media/js/main.js (Lukáš Zaoral)
- hub: remove jQuery from templates (Lukáš Zaoral)
- packaging: bump release to 0.9.1 to distribute newer osh-cli (Kamil Dudka)
- hub: use BigIntegerField for statistical data (Lukáš Zaoral)
- hub: always consider the latest enabled scan (Lukáš Zaoral)
- hub: remove Python 2 remnants (Lukáš Zaoral)
- hub: remove redundant PROJECT_DIR declaration in scripts/stats_updater (Lukáš Zaoral)
- hub: call django.setup() in scripts/stats_updater (Lukáš Zaoral)
- hub: DJANGO_SETTINGS_MODULE must be defined before any Django imports (Lukáš Zaoral)
- hub: execute python3 through env in scripts/stats_updater (Lukáš Zaoral)
- packaging: do not depend on python3-six (Lukáš Zaoral)
- hub: remove Python 2 remnants (Lukáš Zaoral)
- worker: remove calls to kobo.tback.set_except_hook (Lukáš Zaoral)
- worker: do not create redundant tuples (Lukáš Zaoral)
- worker: remove redundant instances of operator % (Lukáš Zaoral)
- worker: use f-strings instead of % operator (Lukáš Zaoral)
- worker: remove redundant class method definitions (Lukáš Zaoral)
- worker: deduplicate {Diff,Mock,VersionDiff}Build (Lukáš Zaoral)
- worker: break a long line in osh-worker (Lukáš Zaoral)
- worker: use print for file writing (Lukáš Zaoral)
- worker: use sys.exit directly in osh-worker (Lukáš Zaoral)
- worker: remove Python 2 remnants (Lukáš Zaoral)
- worker: remove unused __init__.py (Lukáš Zaoral)
- hub: remove TaskExtension model (Lukáš Zaoral)
- hub: replace pipes module with shlex (Lukáš Zaoral)
- hub: remove dead code in waiving/service.py (Lukáš Zaoral)
- hub: remove Python 2 remnants (Lukáš Zaoral)
- hub: remove @public decorator (Lukáš Zaoral)
- hub: remove Python 2 remnants (Lukáš Zaoral)
- hub: remove get_tag_by_name function (Lukáš Zaoral)
- hub: remove other/test_enviroment.py (Lukáš Zaoral)
- hub: remove other/scan.py (Lukáš Zaoral)
- hub: interim fix for the `Create Jira` button (Kamil Dudka)
- hub: fix linter warnings (Pavel Simovec)
- hub: Use inclusive language: blacklisted->blocked (Pavel Simovec)
- hub: remove PackageNotEligibleException (Lukáš Zaoral)
- hub: fix urls pointing to waivers in package details (Lukáš Zaoral)
- docs/development.md: suggest to use a smaller db snapshot by default (Kamil Dudka)
- fix linter warnings (Isabella Basso do Amaral)
- hub/waiving: add jira button (Isabella Basso do Amaral)
- hub/waiving: create reporting submodule (Isabella Basso do Amaral)
- hub: use correct method to mark task as failed (Lukáš Zaoral)
- hub: remove Python 2 remnants (Lukáš Zaoral)
- hub: remove `captureas` template tag (Lukáš Zaoral)
- hub: remove unused result_group_display_* filters (Lukáš Zaoral)
- packaging: common subpackage should own osh/__pycache__ (Lukáš Zaoral)
- hub: fix discovery of tests using manage.py test (Lukáš Zaoral)
- hub: add missing leading '/' to 'scan/mock' url (Lukáš Zaoral)
- hub: fix waiving test fixtures (Lukáš Zaoral)
- hub: use the @admin.register decorator for Admin classes (Lukáš Zaoral)
- hub: use postgresql for database engine in CI config (Lukáš Zaoral)
- hub: simplify some expressions in csmock_parser (Lukáš Zaoral)
- hub: remove superfluous parentheses in csmock_parser (Lukáš Zaoral)
- hub: simplify emptiness check in csmock_parser (Lukáš Zaoral)
- hub: remove redundant usages of the % operator (Lukáš Zaoral)
- hub: use f-strings in instead of % operator in csmock_parser (Lukáš Zaoral)
- hub: remove Results class from csmock_parser (Lukáš Zaoral)
- hub: replace pipes module with shlex (Lukáš Zaoral)
- hub: remove the __all__ declaration in csmock_parser (Lukáš Zaoral)
- hub: remove an unneeded shebang from csmock_parser (Lukáš Zaoral)
- hub: remove Python 2 remnants in csmock_parser (Lukáš Zaoral)
- client: Handle URL prefix change to `/osh` (Siteshwar Vashisht)
- hub: Change URL prefix to `/osh` from `/covscanhub` (Siteshwar Vashisht)
- hub: urls: linter fixes (Isabella Basso do Amaral)
- hub: waiving/views: remove unnecessary docstrings (Isabella Basso do Amaral)
- hub: drop django.conf.urls (Isabella Basso do Amaral)
- hub: get rid of py2 remnants (Isabella Basso do Amaral)
- hub: remove bundled django code (Vincent Mihalkovic)
- hub: remove Python 2 remnants (Vincent Mihalkovic)
- hub: other/shortcuts: remove uneeded parameters from `add_link_field` (Isabella Basso do Amaral)
- hub: other/shortcuts: remove __all__ declaration (Isabella Basso do Amaral)
- hub: other: don't use allow_tags attribute (Isabella Basso do Amaral)
- hub: other: get rid of py2 remnants (Isabella Basso do Amaral)
- hub: other: get rid of `other.admin` (Isabella Basso do Amaral)
- hub: add /upload to .gitignore (Lukáš Zaoral)
- client: rewrite the Bash completion (Lukáš Zaoral)
- client: remove shebang from completion/main.py (Lukáš Zaoral)
- client: implement fetching of profiles for completion (Lukáš Zaoral)
- client: implement fetching of analyzers for completion (Lukáš Zaoral)
- client: restructure the completion code (Lukáš Zaoral)
- client: use default IFS as the option delimiter in completion (Lukáš Zaoral)
- client: store completion pickle cans in ~/.cache (Lukáš Zaoral)
- hub: templates: Drop `admin_static` file sourcing tag (Isabella Basso do Amaral)
- hub: change Model._meta.{module_name -> model_name} (Isabella Basso do Amaral)
- hub: stats/templatetags/filters: move `is_safe` flag to filter decorator (Isabella Basso do Amaral)
- hub: settings*: update deprecated settings (Isabella Basso do Amaral)
- hub: get rid of outdated comments (Isabella Basso do Amaral)
- hub: get rid of py2 remnants (Isabella Basso do Amaral)
- containers: Rename `covscanhub` to `openscanhub` in scripts (Siteshwar Vashisht)
- common: move common/utils/* to common/ (Lukáš Zaoral)
- client: move client configuration parsing to client (Lukáš Zaoral)
- hub: remove support for package eligibility (Lukáš Zaoral)
- hub: remove Python 2 remnants (Lukáš Zaoral)
- hub: remove Capability and PackageCapability models (Lukáš Zaoral)
- hub: remove Python 2 remnants (Lukáš Zaoral)
- packaging: drop covscan-{hub,worker}-conf-{stage,prod} pkgs (Kamil Dudka)
- ci: use a separate copy of settings_local.py (Kamil Dudka)
- packaging: remove %post scriptlet of covscan-worker-conf-* pkgs (Kamil Dudka)
- packaging: remove %post scriptlet of covscan-hub-conf-* pkgs (Kamil Dudka)
- ci: Avoid breaking CI on RPM package name change to `osh` (Siteshwar Vashisht)
- docs: Add initial contribution guidelines (Siteshwar Vashisht)
- packaging: make it possible to use 3rd party *-conf-* packages (Kamil Dudka)
- packaging: remove Obsoletes for hub/worker no longer needed (Kamil Dudka)
- hub: remove scripts/brew_integration.py (Lukáš Zaoral)
- scripts/tls: remove internal script and manual (Kamil Dudka)
- docs: remove internal documentation (Kamil Dudka)
- hub: use json module to serialize dicts in script/umb-emit (Lukáš Zaoral)
- hub: remove Python 2 remnants from scripts/umb-emit (Lukáš Zaoral)
- hub: remove django-debug-toolbar (Lukáš Zaoral)
- hub: fix pyupgrade reports in hub/{settings,urls} (Lukáš Zaoral)
- hub: enable installation of gettext message objects (Lukáš Zaoral)
- common/utils/conf: replace SafeConfigParser with ConfigParser (Lukáš Zaoral)
- common/utils/conf: use f-strings instead of % operator (Lukáš Zaoral)
- common/utils/conf: use print for file writing (Lukáš Zaoral)
- common/utils/conf: remove redundant condition (Lukáš Zaoral)
- common/utils/conf: use inclusive language in comments (Lukáš Zaoral)
- common/utils/conf: remove get_home_dir function (Lukáš Zaoral)
- common/utils/conf: remove the __all__ declaration (Lukáš Zaoral)
- common/utils/conf: remove Python 2 remnants (Lukáš Zaoral)
- worker: Rename `covscand.service` to `osh-worker.service` (Siteshwar Vashisht)
- Revert "client: use -s to disable the Python user site directory" (Lukáš Zaoral)
- hub: remove deprecated NullBooleanField (Vincent Mihalkovic)
- client: deduplicate use of fetch_results (Lukáš Zaoral)
- client: fix diff-build with --download-results and --srpm (Lukáš Zaoral)
- Fix scan change form buttons urls (Jiri Kucera)
- setup.py: remove redundant shebang (Lukáš Zaoral)
- client: execute python3 through env (Lukáš Zaoral)
- worker: fix pyupgrade reports in osh-worker (Lukáš Zaoral)
- client: execute python3 through env (Lukáš Zaoral)
- client: use -s to disable the Python user site directory (Lukáš Zaoral)
- client: fix isort report in osh-cli (Lukáš Zaoral)
- hub: remove deprecated fields from waiving_results table (Lukáš Zaoral)
- hub: fix pyupgrade reports in waiving/models (Lukáš Zaoral)
- hub: remove decode_pickle function from scan/models (Lukáš Zaoral)
- hub: remove ACTUAL_SCANNER from AppSettings (Lukáš Zaoral)
- hub: convert WAIVER_IS_OVERDUE into an integer (Lukáš Zaoral)
- hub: remove WAIVER_IS_OVERDUE_RELSPEC from AppSettings (Lukáš Zaoral)
- config: remove redundant ignores from flake8 configuration (Lukáš Zaoral)
- hub: fix invalid quotation in templates/stats/detail (Lukáš Zaoral)
- hub: remove obsolete middleware module (Lukáš Zaoral)
- Revert "worker: Rename `covscand.service` to `osh-worker.service`" (Kamil Dudka)
- worker: Rename `covscand.service` to `osh-worker.service` (Siteshwar Vashisht)
- worker: Explicitly set pid file path in worker invocation (Siteshwar Vashisht)
- worker: Fix path to worker directory in a comment (Siteshwar Vashisht)
- hub: Remove `osh/hub/scripts/finish_scan.py` script (Siteshwar Vashisht)
- client: Remove commented out internal URLs (Siteshwar Vashisht)
- hub: fix render failure of package details without base build (Lukáš Zaoral)
- hub: fix pyupgrade reports in scan/models (Lukáš Zaoral)
- containers: use correct username for database restore (Lukáš Zaoral)
- ci: execute pyupgrade before other linters (Lukáš Zaoral)
- hub: Rename `covscan` to `OpenScanHub` (Siteshwar Vashisht)
- ci: add pyupgrade to pre-commit (Lukáš Zaoral)
- worker: Rename `covscand.pid` to `osh-worker.pid` (Siteshwar Vashisht)
- hub: remove scripts/db.py (Lukáš Zaoral)
- hub: Rename `covscan` to `OpenScanHub` in comments (Siteshwar Vashisht)
- client: Remove unused coverity options (Siteshwar Vashisht)
- hub: Rename UMB client certificate (Siteshwar Vashisht)
- hub: Rename `covscan` to `OpenScanHub` (Siteshwar Vashisht)
- client: remove redundant dependency on python3-six (Lukáš Zaoral)
- client: remove the rest of Python 2 remnants (Lukáš Zaoral)
- hub: Rename `covscanhub` to `openscanhub` in logger (Siteshwar Vashisht)
- packaging: make it possible to build covscan-client for EPEL-9 (Kamil Dudka)
- bump release to 0.9.0 to distribute newer covscan-client (Kamil Dudka)
- client/commands/cmd_download_results: move NVR check to a separate method (Lukáš Zaoral)
- client/commands/cmd_download_results: support tasks with NVR in the brew_build key (Lukáš Zaoral)
- client: Rename `covscan` to `osh-cli` in help text (Siteshwar Vashisht)
- worker: Rename `covscand.log` to `worker.log` (Siteshwar Vashisht)
- client/osh-cli: reformat the code a bit (Lukáš Zaoral)
- client/osh-cli: use sys.exit directly (Lukáš Zaoral)
- client/osh-cli: use print for file writing (Lukáš Zaoral)
- client/osh-cli: factor-out handling of deprecated options (Lukáš Zaoral)
- client/osh-cli: remove unused code (Lukáš Zaoral)
- client/osh-cli: remove Python 2 remnants (Lukáš Zaoral)
- client/completion/osh-cli.bash: fix --config= completion (Lukáš Zaoral)
- client/completion/main: introduce argument parsing (Lukáš Zaoral)
- client/completion/main: use HubProxy to connect to the hub (Lukáš Zaoral)
- client/completion/main: do not cache results from a failed query (Lukáš Zaoral)
- client/completion/main: use correct configuration file (Lukáš Zaoral)
- client/completion/main: catch OSError instead of IOError (Lukáš Zaoral)
- client/completion/main: remove Python 2 remnants (Lukáš Zaoral)
- hub: Remove stale reference to `/tmp/covscanhub_extract_tarball.log` (Siteshwar Vashisht)
- client: move completion module to client directory (Lukáš Zaoral)
- spec: use the %bash_completions_dir macro for BASH completions (Lukáš Zaoral)
- client: rename bash_completion.d to completion (Lukáš Zaoral)
- client: Fix a stale comment in `osh-cli` (Siteshwar Vashisht)
- config: remove misleading worker authentication method recommendation (Lukáš Zaoral)
- config: replace deprecated krbv AUTH_METHOD with gssapi (Lukáš Zaoral)
- packaging: Use "OpenScanHub" name in summary (Siteshwar Vashisht)
- Rename `covscanhub.wsgi` to `osh-hub.wsgi` (Siteshwar Vashisht)
- Rename `covscand` script to `osh-worker` (Siteshwar Vashisht)
- Remove references to `Coverity scan scheduler` (Siteshwar Vashisht)
- CI: Remove stale `/etc/httpd/conf.d/covscanhub-httpd.conf` file if it exists (Siteshwar Vashisht)
- client/commands/shortcuts: simplify verify_brew_koji_build (Lukáš Zaoral)
- covscan/commands/shortcuts: do not use exceptions needlessly (Lukáš Zaoral)
- client/commands/shortcuts: simplify handle_perm_denied (Lukáš Zaoral)
- client/commands/shortcuts: simplify verify_build_exists (Lukáš Zaoral)
- client/commands/shortcuts: use f-strings where possible (Lukáš Zaoral)
- client/commands/shortcuts: remove the __all__ declaration (Lukáš Zaoral)
- client/commands/shortcuts: remove Python 2 remnants (Lukáš Zaoral)
- client/commands/cmd_list_mock_configs: use super() for superclass access (Lukáš Zaoral)
- client/commands/cmd_mock_build: use absolute imports (Lukáš Zaoral)
- client/commands/cmd_mock_build: remove Python 2 remnants (Lukáš Zaoral)
- client: handle the --hub option globally (Lukáš Zaoral)
- client/__init__: use print for file writing (Lukáš Zaoral)
- client/__init__: remove the __all__ declaration (Lukáš Zaoral)
- client/__init__: fix import of kobo.client.ClientCommand (Lukáš Zaoral)
- client/__init__: remove Python 2 remnants (Lukáš Zaoral)
- docs/deployment.md: update instructions about mount points (Kamil Dudka)
- Rename `covscanhub-httpd.conf` to `osh-hub-httpd.conf` (Siteshwar Vashisht)
- Rename `covscan-xmlrpc-client.py` to `osh-xmlrpc-client.py` (Siteshwar Vashisht)
- Rename `covscanhub-minimal.db.gz` to `openscanhub-minimal.db.gz` (Siteshwar Vashisht)
- Fix path to bash completions (Siteshwar Vashisht)
- Rename `covscan` to `osh-cli` in bash completions (Siteshwar Vashisht)
- hub/settings_local.py: do not create ./covscanhub dir (Kamil Dudka)
- Merge all jobs with tag `gitlab-ci-build-on-copr` (Siteshwar Vashisht)
- Remove `cf_devel_whiteboard` field (Siteshwar Vashisht)
- Remove references to `Red Hat` from home page (Siteshwar Vashisht)
- Rename `CovScanCommand` class to `OshCommand` in client (Siteshwar Vashisht)
- Remove references to `covscan` in client configurations (Siteshwar Vashisht)
- Remove references to `Red Hat` in base template (Siteshwar Vashisht)
- Rename `Covscan` to `OpenScanHub` on main index page (Siteshwar Vashisht)
- Rename Covscan client(`covscan`) to `osh-cli` (Siteshwar Vashisht)
- Rename `covscan.conf` to `client.conf` (Siteshwar Vashisht)
- Rename `covscan-local.conf` to `client-local.conf` (Siteshwar Vashisht)
- Update docs to handle migration to `osh/hub` (Siteshwar Vashisht)
- Update spec file to handle migration to `osh/hub` (Siteshwar Vashisht)
- Fix linter warnings (Siteshwar Vashisht)
- Rename `covscanhub` directory to `osh/hub` (Siteshwar Vashisht)
- Rename `COVSCAN_CONFIG_FILE` environment variable (Siteshwar Vashisht)
- Use kobo.rpmlib to parse NVRs (Jiri Kucera)
- covscanhub/scan/compare.py: Remove encoding mark (Jiri Kucera)
- covscanhub/scan: Refactor get_compare_title (Jiri Kucera)
- Add more tests for get_compare_title (Jiri Kucera)
- Rename `COVSCAND_CONFIG_FILE` environment variable (Siteshwar Vashisht)
- Rename `covscand.conf` to `worker.conf` (Siteshwar Vashisht)
- utils/config.py: fix a misleading error message (Kamil Dudka)
- client/commands/cmd_task_info: only accept numbers as task ids (Lukáš Zaoral)
- client/commands/cmd_download_results: only accept numbers as task ids (Lukáš Zaoral)
- client/covscan_api: remove CovscanAPI module (Lukáš Zaoral)
- Add priority offset feature (Tomas Korbar)
- Rename `covscand-local.conf` to `worker-local.conf` (Siteshwar Vashisht)
- client/commands/cmd_list_profiles: use f-strings where possible (Lukáš Zaoral)
- client/commands/cmd_list_profiles: remove Python 2 remnants (Lukáš Zaoral)
- client/commands/cmd_list_mock_configs: use f-strings where possible (Lukáš Zaoral)
- client/commands/cmd_list_mock_configs: remove Python 2 remnants (Lukáš Zaoral)
- client/commands/cmd_task_info: print error messages to stderr (Lukáš Zaoral)
- client/commands/cmd_task_info: use f-strings where possible (Lukáš Zaoral)
- client/commands/cmd_task_info: simplify control flow (Lukáš Zaoral)
- client/commands/cmd_task_info: remove commented-out code (Lukáš Zaoral)
- client/commands/cmd_task_info: remove Python 2 remnants (Lukáš Zaoral)
- client/commands/analyzers: remove empty file (Lukáš Zaoral)
- client/commands/analyzers: move contents to shortcuts (Lukáš Zaoral)
- client/commands/analyzers: remove Python 2 remnants (Lukáš Zaoral)
- docs/umb.md: renewal of UMB client certificates (Kamil Dudka)
- client/commands/cmd_find_tasks: simplify control flow (Lukáš Zaoral)
- client/commands/cmd_find_tasks: use f-strings where possible (Lukáš Zaoral)
- client/commands/cmd_find_tasks: remove dead code (Lukáš Zaoral)
- client/commands/cmd_find_tasks: remove Python 2 remnants (Lukáš Zaoral)
- client/commands/cmd_version_diff_build: fail when mock profile does not exist (Lukáš Zaoral)
- client/commands/cmd_version_diff_build: remove Python 2 remnants (Lukáš Zaoral)
- Remove `covscanhub/service/waiving.py` (Siteshwar Vashisht)
- Exclude kobo from namespace packages in setup.py (Lumir Balhar)
- Remove get_files function from include.py (Lumir Balhar)
- client/commands/common: remove deprecated options (Lukáš Zaoral)
- client/commands/cmd_list_analyzers: simplify usage example (Lukáš Zaoral)
- client/command/cmd_list_analyzers: do not list short options (Lukáš Zaoral)
- client/commands/cmd_list_analyzers: use f-strings where possible (Lukáš Zaoral)
- client/commands/cmd_list_analyzers: remove Python 2 remnants (Lukáš Zaoral)
- update .git-blame-ignore-revs (Isabella Basso do Amaral)
- docs/hw.ods: record recycling of the cov04 parts in cov03 (Kamil Dudka)
- covscan/commands/cmd_download_results: inform the user about downloaded archives (Lukáš Zaoral)
- covscan/commands/cmd_download_results: do not use exceptions needlessly (Lukáš Zaoral)
- covscan/commands/cmd_download_results: fix download of results (Lukáš Zaoral)
- covscan/commands/cmd_download_results: properly handle non-existent tasks (Lukáš Zaoral)
- covscan/commands/cmd_download_results: remove redundant tasks variable (Lukáš Zaoral)
- covscan/commands/cmd_download_results: use f-strings where possible (Lukáš Zaoral)
- covscan/commands/cmd_download_results: simplify output directory handling (Lukáš Zaoral)
- covscan/commands/cmd_download_results: formatting fixes (Lukáš Zaoral)
- covscan/commands/cmd_download_results: remove Python 2 remnants (Lukáš Zaoral)
- Fix linter warnings (Siteshwar Vashisht)
- Rename `covscan` directory to `osh/client` (Siteshwar Vashisht)
- .gitignore: move `/static/` entry to the covscanhub folder (Isabella Basso do Amaral)
- hub: fix `collectstatic` call (Isabella Basso do Amaral)
- Use Input widget for ForeignKeys (Jiri Kucera)
- covscanhub/static: drop from the git repo (Kamil Dudka)
- drop `fake-django` and `patches` directories (Kamil Dudka)
- Update to newer version of `isort` in `pre-commit` configurations (Siteshwar Vashisht)
- docs/development: add gitlab-job-guard user instructions (Isabella Basso do Amaral)
- docs/development: fix md verbatim syntax (Isabella Basso do Amaral)
- gitlab-ci: fix `GITLAB_API_TOKEN` sourcing (Isabella Basso do Amaral)
- gitlab-ci: get rid of redundant covscan-ci-runner tasks (Isabella Basso do Amaral)
- containers/scripts/deploy: fix --force behavior (Isabella Basso do Amaral)
- gitlab-ci: specify containers to `compose down` (Isabella Basso do Amaral)
- Fix linter warnings (Siteshwar Vashisht)
- Rename `covscancommon` directory to `osh/common` (Siteshwar Vashisht)
- covscanhub/waiving/tests: use fixtures to test scan availability (Isabella Basso do Amaral)
- covscanhub/waiving/tests: use Django test class (Isabella Basso do Amaral)
- covscanhub/waiving/tests: linter fixes (Isabella Basso do Amaral)
- covscanhub/waiving/tests: remove `AssetsTestCase` (Isabella Basso do Amaral)
- covscanhub/waiving/tests: remove legacy testing code (Isabella Basso do Amaral)
- gitlab-ci: update linter job image to latest Fedora (Isabella Basso do Amaral)
- Update instructions to set up `covscan-ci-runner` (Siteshwar Vashisht)
- `covscan-common` package should own `%{python3_sitelib}/osh` directory (Siteshwar Vashisht)
- Fix warnings reported by Flake8 (Siteshwar Vashisht)
- Rename `covscand` directory to `osh/worker` (Siteshwar Vashisht)
- covscanhub: avoid traceback of manage.py with Django 4.x (Kamil Dudka)
- covscanhub/scan/admin.py: linter fixes (Kamil Dudka)
- bash scripts: fix indentation (Isabella Basso do Amaral)
- docs/development: add subsection regarding `init-db.sh` usage (Isabella Basso do Amaral)
- containers/scripts: add --help option (Isabella Basso do Amaral)
- containers/hub/run: fix `shellcheck` warnings... (Isabella Basso do Amaral)
- containers/scripts/gen_integration_test_cov: use init-db script for deployment (Isabella Basso do Amaral)
- containers/scripts: merge build and deploy scripts (Isabella Basso do Amaral)
- containers/scripts: merge database restore into init-db script (Isabella Basso do Amaral)
- containers/scripts/utils: provide `wait_for_db()` helper (Isabella Basso do Amaral)
- scripts: make sourcing clearer (Isabella Basso do Amaral)
- containers/scripts/utils: rewrite script to not provoke runtime errors (Isabella Basso do Amaral)
- scripts/cli_sanity_test: simplify script to run only on deployed env (Isabella Basso do Amaral)
- Move container related scripts to unified location (Isabella Basso do Amaral)
- covscand/.gitignore: ignore log rotations (Isabella Basso do Amaral)
- containers/worker.Dockerfile: install csmock-plugin-unicontrol (Kamil Dudka)
- Add integration tests for differential builds (Siteshwar Vashisht)
- Add integration test for `covscanhub/scripts/covscan-xmlrpc-client.py` (Siteshwar Vashisht)
- Add more integration tests for the client (Siteshwar Vashisht)
- Run worker tasks in foreground in CI (Siteshwar Vashisht)
- docs/deployment.md: make log rotation work with SELinux (Kamil Dudka)
- gitlab-ci: stop enabling services (Isabella Basso do Amaral)
- gitlab-ci: make path changes temporary with subshell (Isabella Basso do Amaral)
- gitlab-ci: use `pipefail` option when redirecting `rhcopr` output (Isabella Basso do Amaral)
- gitlab-ci: refactor script in pseudo-workflows (Isabella Basso do Amaral)
- gitlab-ci: add gitlab-job-guards (Isabella Basso do Amaral)
- gitlab-ci: remove unused stages (Isabella Basso do Amaral)
- .gitignore: add files produced by generate_integration_test_coverage.sh (Kamil Dudka)
- covscand/.gitignore: add directories created by hub (Kamil Dudka)
- .gitignore: ignore files produced by python (Kamil Dudka)
- .gitignore: make some entries more specific (Kamil Dudka)
- .gitignore: remove obsolete entries (Kamil Dudka)
- .gitignore,Makefile: drop MANIFEST (Kamil Dudka)
- delete unused script files (Isabella Basso do Amaral)
- covscand: introduce RUN_TASKS_IN_FOREGROUND in covscand.conf (Kamil Dudka)
- Fix names of dockerfiles in integration test coverage script (Siteshwar Vashisht)
- Add link to integration test coverage in development docs (Siteshwar Vashisht)
- update .git-blame-ignore-revs (Isabella Basso do Amaral)
- remove unused files (Isabella Basso do Amaral)
- change fixture user to be csmock instead of coverity (Isabella Basso do Amaral)
- covscanhub/templates/*.html: remove coverity mentions (Isabella Basso do Amaral)
- linter fixes (Isabella Basso do Amaral)
- docs/solutions_to_problems: remove coverity related entry (Isabella Basso do Amaral)
- covscanhub/scan/service: change coverity mentions to csmock (Isabella Basso do Amaral)
- covscanhub: change actual_scanner to csmock (Isabella Basso do Amaral)
- covscanhub: remove DEFAULT_SCANNING_COMMAND field (Isabella Basso do Amaral)
- covscanhub/scan/fixtures/initial_data: remove coverity related configs (Isabella Basso do Amaral)
- covscanhub/waiving/bugzilla_reporting: remove coverity related info (Isabella Basso do Amaral)
- covscanhub/scan/notify: remove coverity warning from message (Isabella Basso do Amaral)
- covscan/commands: remove no_cov option (Isabella Basso do Amaral)
- Add GitLab job artifact for integration tests (Siteshwar Vashisht)
- Makefile: add options for managing containers (Isabella Basso do Amaral)
- Makefile: small fixes (Isabella Basso do Amaral)
- docker-compose: add build options and profiles (Isabella Basso do Amaral)
- scrips/build: optimize env checks (Isabella Basso do Amaral)
- containers: change order of tasks (Isabella Basso do Amaral)
- containers: make file extensions more explicit (Isabella Basso do Amaral)
- Generate coverage report for integration tests (Siteshwar Vashisht)
- update .git-blame-ignore-revs (Isabella Basso do Amaral)
- covscanhub/templates/stats/detail.html: linter fix (Isabella Basso do Amaral)
- covscanhub/templates/*.html: update static file sourcing (Isabella Basso do Amaral)
- update .git-blame-ignore-revs (Isabella Basso do Amaral)
- linter fixes (Isabella Basso do Amaral)
- covscan/commands/cmd_diff_build: remove `-m` option (Isabella Basso do Amaral)
- `kobo` directory is automatically removed in GitLab CI (Siteshwar Vashisht)
- ci: add init-db-script CI job (Kamil Dudka)
- covscanhub/scripts/*.py: linter fixes (Isabella Basso do Amaral)
- covscanhub/scripts/*.py: improve code to find project root (Isabella Basso do Amaral)
- Use `sleep inf` in `osh-client` container (Siteshwar Vashisht)
- update .git-blame-ignore-revs (Isabella Basso do Amaral)
- scripts/utils: make `wait_for_container` function more general (Isabella Basso do Amaral)
- covscancommon/utils/conf.py: simplify call to find $HOME env variable (Isabella Basso do Amaral)
- covscancommon/utils/completion.py: source correct conf file (Isabella Basso do Amaral)
- covscancommon/utils/conf: simplify homepath retrieval (Isabella Basso do Amaral)
- fix linter errors (Isabella Basso do Amaral)
- covscan*/*.py: improve file handling using 'with' block (Isabella Basso do Amaral)
- Add link to test coverage report for django unit tests (Siteshwar Vashisht)
- covscan.spec: do not replace settings_local.py* on update (Kamil Dudka)
- covscan.spec: make secret_key writable by root only (Kamil Dudka)
- covscan.spec: append log of the %post scriptlet (Kamil Dudka)
- Add artifact for django unit tests coverage (Siteshwar Vashisht)
- Rename `test` job to `django-unit-tests` (Siteshwar Vashisht)
- Rename `run-errata` to `run-errata-test` in stages (Siteshwar Vashisht)
- Add a test for errata in GitLab CI (Siteshwar Vashisht)
- Fix remaining unit tests (Jiri Kucera)
- `covscan-xmlrpc-client.py` should return 0 on success (Siteshwar Vashisht)
- gitlab-ci, covscanhub/settings_local: add test database config (Isabella Basso do Amaral)
- gitlab-ci: print summary for tests (Isabella Basso do Amaral)
- gitlab-ci: give covscanhub needed privileges to run tests (Isabella Basso do Amaral)
- gitlab-ci: update containers up command (Isabella Basso do Amaral)
- docker-compose: remove unneeded/incorrect options (Isabella Basso do Amaral)
- Use custom GitLab CI runner for Copr builds (Siteshwar Vashisht)
- Add a note about name of Copr project for merge requests (Siteshwar Vashisht)
- setup.py: Remove usage of distutils (Lumir Balhar)
- covscanhub/settings.py: move common options here (Kamil Dudka)
- covscanhub/settings_local.prod.py: drop `migration` db (Kamil Dudka)
- covscanhub/settings_local*.py: drop QPID_CONNECTION (Kamil Dudka)
- .git-blame-ignore-revs: list of commits to ignore by git-blame (Kamil Dudka)
- Use `ls` instead of `echo` while listing packages (Siteshwar Vashisht)
- Test installation of Copr builds (Siteshwar Vashisht)
- Modify how `rhcopr` configuration is built in CI (Siteshwar Vashisht)
- Enable Copr builds for every update on GitLab (Siteshwar Vashisht)
- Use 'OpenScanHub' name in development docs and containers (Siteshwar Vashisht)
- covscanhub: override dummy SECRET_KEY by a real secret (Kamil Dudka)
- covscanhub/settings_local*.py: fix flake8 warnings (Kamil Dudka)
- covscan.spec: move .pyc files into correct subpkgs (Kamil Dudka)
- Remove useless commented-out code (Lumir Balhar)
- Remove useles piece of code from waiving results template (Lumir Balhar)
- Fix problems identified by linters (Lumir Balhar)
- Switch from .iteritems to .items in templates (Lumir Balhar)
- Add note about running worker (Siteshwar Vashisht)
- docs/deployment.md: minor correction (Kamil Dudka)
- Add note about how to watch task logs (Siteshwar Vashisht)
- Add mod_ssl as runtime dependency (Siteshwar Vashisht)
- Allow all hostnames while running django locally (Siteshwar Vashisht)
- covscanhub: add migration for the last change (Kamil Dudka)
- covscanhub: eliminate a warning of `manage.py check` (Kamil Dudka)
- covscan.spec: apply migrations automatically on upgrade (Kamil Dudka)
- covscan.spec: move systemd scriptlets to -worker subpkg (Kamil Dudka)
- covscanhub: request.user.is_authenticated is a property (Lukáš Zaoral)
- covscanhub/middleware.py: reformat to make precommit happy (Lukáš Zaoral)
- covscanhub/waiving/forms.py: reformat to make precommit happy (Lukáš Zaoral)
- bump version to update production hub URL (Kamil Dudka)
- mass rename *.brq.redhat.com -> *.brq2.redhat.com (Kamil Dudka)
- covscanhub-httpd.conf.stage: re-enable redirect to HTTPS (Kamil Dudka)
- covscan*: fix flake8 reports (Kamil Dudka)
- docs: expect production db to be consistent again (Kamil Dudka)
- INSTALL*: remove obsolete documentation (Kamil Dudka)
- csmock_parser: mitigate shell injection via --csmock-args (Kamil Dudka)
- csmock_parser: unimplement the use_sudo flag (Kamil Dudka)
- csmock_parser: eliminate flake8 warnings (Kamil Dudka)
- covscan.spec: create /var/lib/covscanhub/worker (Kamil Dudka)
- docs/development.md: create non-privileged user named `user` (Kamil Dudka)
- covscanhub-httpd.conf: explicitly set UTF-8 locale for WSGI (Kamil Dudka)
- docs/deployment.md: extend the instructions for covscan prod (Kamil Dudka)
- covscanhub: eliminate an explicit close() in add_title_to_json() (Kamil Dudka)
- covscanhub: load JSON with utf-8 encoding in add_title_to_json() (Kamil Dudka)
- covscanhub/service/processing.py: fix flake8 reports (Kamil Dudka)
- docs/hw.ods: reflect the swap of cov01 <--> cov06 (Kamil Dudka)
- docs/development.md: use the units package for testing (Kamil Dudka)
- Fix or ignore issues found by linters (Lumir Balhar)
- Remove deprecated setting MIDDLEWARE_CLASSES (Lumir Balhar)
- containers: load initial data into db automatically (Kamil Dudka)
- covscanhub: remove unmaintained fixtures (Kamil Dudka)
- docs/deployment.md: document deployment of RHEL-8 staging hub (Kamil Dudka)
- Replace `docker` with `podman` in development docs (Siteshwar Vashisht)
- covscanhub: make WAIVER_IS_OVERDUE* setting work again (Kamil Dudka)
- covscanhub/scan/models.py: fix flake8 reports (Kamil Dudka)
- Remove empty or outdated files (Lumir Balhar)
- We don't ship %doc or %license in RPM - we don't need them in sdist (Lumir Balhar)
- Build process now depends on python3-setuptools (Lumir Balhar)
- Scripts are now installed by default, remove what is not needed (Lumir Balhar)
- Do not use $RPM_BUILD_ROOT anymore (Lumir Balhar)
- Fix packages discovery automation with setuptools (Lumir Balhar)
- containers/Dockerfile.*: use fastest mirror available (Isabella Basso do Amaral)
- containers/Dockerfile.*: add parallel downloads (Isabella Basso do Amaral)
- bump version to make upgrades to git snapshots work again (Kamil Dudka)
- Detect tags for HEAD automatically (Lumir Balhar)
- Improved and simplified setup.py and makefile for SRPM (Lumir Balhar)
- deploy.sh: remove legacy deploy script (Isabella Basso do Amaral)
- docker, scripts: add client dockerfile (Isabella Basso do Amaral)
- docker-compose: make services not autostart by default (Isabella Basso do Amaral)
- scripts/cli_sanity_test.sh, covscanhub/scan/fixtures/: update version of mock test packages (Isabella Basso do Amaral)
- covscanhub/{scan,errata}/fixtures/: fix whitespace errors in files (Isabella Basso do Amaral)
- Dockerfile.hub: drop curl to check container status (Isabella Basso do Amaral)
- covscan/covscan-local.conf: change default HUB_URL config to standard hostname (Isabella Basso do Amaral)
- docker-compose: specify hostnames on file (Isabella Basso do Amaral)
- containers/Dockerfile.*: Remove outdated comments (Isabella Basso do Amaral)
- scripts/{build,utils}.sh: use docker instead of podman if host is on MacOS (Isabella Basso do Amaral)
- *.sh: add shellcheck disable directive to imports (Isabella Basso do Amaral)
- *.sh: generalize shebangs to use env variable instead (Isabella Basso do Amaral)
- files/etc/*/covscand, covscan.spec, setup.py: update init script to be a systemd service (Isabella Basso do Amaral)
- Move commands from Makefile to Gitlab config (Lumir Balhar)
- Add section about Gitlab runner to dev docs (Lumir Balhar)
- Add isort to pre-commit (Lumir Balhar)
- Improve configuration of flake8 (Lumir Balhar)
- Gitlab CI config (Lumir Balhar)
- Initial configuration for pre-commit and flake8 (Lumir Balhar)
- docs/hw.ods: record the purchase of cov06 (Kamil Dudka)
- covscanhub/manage.py: use python3 in shebang (Kamil Dudka)
- covscan.spec: covscan-hub does not require yum any more (Kamil Dudka)
- covscanhub/errata: Remove dead code (Jiri Kucera)
- docs/development.md: remove outdated note (Kamil Dudka)
- Handle non-decodable characters (Jiri Kucera)
- docs/umb.md: minor formatting fix (Kamil Dudka)
- covscanhub: update UMB_BROKER_URLS (Kamil Dudka)
- docs/umb.md: update info about client certificates (Kamil Dudka)
- css: wrap long lines in waiver messages (Kamil Dudka)
- Unit testing in covscan (Jiri Kucera)
- docs/umb.md: update URL to updated instructions (Kamil Dudka)
- docs/umb.md: update URL for certificate management (Kamil Dudka)
- covcanhub: update top-level web page (Kamil Dudka)
- Track also generated version.py file for covscancommon (Lumir Balhar)
- Move covscan.utils to covscancommon (Lumir Balhar)
- Reorganize specfile with new covscan-common subpackage (Lumir Balhar)
- Create covscancommon with shared modules to break dependencies (Lumir Balhar)
- covscan.spec: add obsoletes to ease upgrade (Kamil Dudka)
- Make it possible to import production database to dev environment (Lumir Balhar)
- Fix pagination (issue #30) (Jiri Kucera)
- covscanhub: port to the new Bugzilla API (Kamil Dudka)
- docs/el7-to-el8-migration.md: record migration of cov0{2..5} (Kamil Dudka)
- covscan.spec: provide all configuration alternatives (Kamil Dudka)
- covscanhub: update URL of testing Bugzilla instance (Kamil Dudka)
- covscanhub: update configuration for el8 staging instance (Kamil Dudka)
- Use sclorg PostgreSQL container (Jiri Kucera)
- Remove useless testing code (Lumir Balhar)

* Wed May 17 2023 Kamil Dudka <kdudka@redhat.com> - 0.9.3-1
- rename covscan-* packages to osh-*

* Tue Apr 25 2023 Lukáš Zaoral <lzaoral@redhat.com> - 0.9.2-1
- revert osh-cli to use an absolute path to python3

* Fri Apr 14 2023 Kamil Dudka <kdudka@redhat.com> - 0.9.1-1
- let osh-cli use hub URL with the new /osh prefix

* Thu Mar 16 2023 Kamil Dudka <kdudka@redhat.com> - 0.9.0-1
- stabilize the refactored version of covscan-client

* Thu Sep 01 2022 Siteshwar Vashisht <svashisht@redhat.com> - 0.8.2-2
- Add mod_ssl as runtime dependency

* Wed Aug 24 2022 Kamil Dudka <kdudka@redhat.com> - 0.8.2-1
- update production hub URL in default configuration of covscan-client

* Fri Jun 17 2022 Kamil Dudka <kdudka@redhat.com> - 0.8.1-1
- bump version to make upgrades to git snapshots work again

* Thu Apr 07 2022 Lumír Balhar <lbalhar@redhat.com> - 0.8.0-3
- Reorganize specfile and add covscan-common

* Mon Mar 14 2022 Kamil Dudka <kdudka@redhat.com> - 0.8.0-2
- add obsoletes to ease upgrade

* Thu Jan 20 2022 Kamil Dudka <kdudka@redhat.com> - 0.8.0-1
- drop support for python 2.x and django 1.x
- new major release

* Thu Nov 04 2021 Kamil Dudka <kdudka@redhat.com> - 0.7.2-1
- new release

* Thu Mar 25 2021 Kamil Dudka <kdudka@redhat.com> - 0.7.1-1
- new release

* Tue Dec 22 2020 Kamil Dudka <kdudka@redhat.com> - 0.7.0-1
- new release

* Thu Oct 24 2019 Matej Mužila <mmuzila@redhat.com> - 0.6.12-3
- spec changes to build python3 covscan

* Thu Sep 19 2019 Kamil Dudka <kdudka@redhat.com> - 0.6.12-2
- explicitly require python2-* build dependencies

* Tue Sep 03 2019 Kamil Dudka <kdudka@redhat.com> - 0.6.12-1
- new release

* Fri Oct 19 2018 Kamil Dudka <kdudka@redhat.com> - 0.6.11-1
- new release

* Mon Aug 13 2018 Kamil Dudka <kdudka@redhat.com> - 0.6.10-1
- new release

* Fri Oct 20 2017 Kamil Dudka <kdudka@redhat.com> - 0.6.9-1
- new release

* Mon Jun 26 2017 Kamil Dudka <kdudka@redhat.com> - 0.6.8-1
- new release

* Tue Apr 12 2016 Kamil Dudka <kdudka@redhat.com> - 0.6.7-2
- bump release to force update if stale covscan-testing packages are installed

* Thu Aug 20 2015 Kamil Dudka <kdudka@redhat.com> - 0.6.7-1
- 0.6.7 bugfix release

* Wed Aug 12 2015 Kamil Dudka <kdudka@redhat.com> - 0.6.6-1
- 0.6.6 bugfix release
- update the list of dependencies
- create empty /var/log/covscanhub.log unless it exists already

* Thu Feb 19 2015 Tomas Tomecek <ttomecek@redhat.com> - 0.6.5-1
- 0.6.5 bugfix release

* Wed Dec 10 2014 Tomas Tomecek <ttomecek@redhat.com> - 0.6.4-1
- update CLI docs (--help) and homepage
- workaround a race on server when running multiple tasks

* Tue Nov 04 2014 Tomas Tomecek <ttomecek@redhat.com> - 0.6.3-1
- enable passing args to csmock from client
- fix several TBs

* Mon Oct 20 2014 Tomas Tomecek <ttomecek@redhat.com> - 0.6.2-1
- enable submitting prio from cli
- pass cmock args to version task

* Mon Oct 13 2014 Tomas Tomecek <ttomecek@redhat.com> - 0.6.1-1
- bugfix update: fix version-diff-build

* Sat Oct 11 2014 Tomas Tomecek <ttomecek@redhat.com> - 0.6.0-1
- 0.6.0 release
- add profiles

* Thu Sep 25 2014 Tomas Tomecek <ttomecek@redhat.com> - 0.6.0-1.a
- 0.6.0a alpha release

* Mon Aug 04 2014 Tomas Tomecek <ttomecek@redhat.com> - 0.5.2-1
- add DB fixtures to package

* Mon Aug 04 2014 Tomas Tomecek <ttomecek@redhat.com> - 0.5.1-1
- fixes for reworked scheduler

* Wed Jan 8 2014 Tomas Tomecek <ttomecek@redhat.com> - 0.4.4-1
- remove brewkoji dependency

* Sun Nov 17 2013 Tomas Tomecek <ttomecek@redhat.com> - 0.4.3-1
- hub update (django and kobo rebase)

* Fri Oct 18 2013 Tomas Tomecek <ttomecek@redhat.com> - 0.4.2-2
- update kobo dependency (0.4.1 should be fine)
- add scriptlets for handling issues with kobo-0.4.0

* Mon Sep 30 2013 Tomas Tomecek <ttomecek@redhat.com> - 0.4.1-2
- make dependency to kobo 0.3.8 (0.4 is broken currently)

* Fri Sep 13 2013 Tomas Tomecek <ttomecek@redhat.com> - 0.4.1-1
- improve stats
- bugfixes

* Wed Sep 11 2013 Tomas Tomecek <ttomecek@redhat.com> - 0.4.0-1
- new version of hub and client

* Mon Jun 03 2013 Tomas Tomecek <ttomecek@redhat.com> - 0.3.2-3
- store provider requests in DB (hub)

* Thu May 23 2013 Tomas Tomecek <ttomecek@redhat.com> - 0.3.2-2
- New release of hub, bugfixes and RFEs
- Getting ready for 6.5 scanning

* Thu May 23 2013 Tomas Tomecek <ttomecek@redhat.com> - 0.3.2-1
- Update to version 0.3.2

* Wed Apr 24 2013 Tomas Tomecek <ttomecek@redhat.com> - 0.3.1-1
- Update to version 0.3.1

* Fri Apr 5 2013 Tomas Tomecek <ttomecek@redhat.com> - 0.3.0-1
- Update for hub and worker
- ET pilot

* Fri Mar 15 2013 Tomas Tomecek <ttomecek@redhat.com> - 0.2.3-1
- Let client depend on brewkoji
- new version

* Thu Jan 24 2013 Tomas Tomecek <ttomecek@redhat.com> - 0.2.2-2
- Tarball extraction fix

* Wed Jan 09 2013 Tomas Tomecek <ttomecek@redhat.com> - 0.2.2-1
- Added support for multiple new options (CLI)

* Tue Nov 06 2012 Tomas Tomecek <ttomecek@redhat.com> - 0.2.1-2
- Updated requirements for hub and worker

* Thu Nov 1 2012 Tomas Tomecek <ttomecek@redhat.com> - 0.2.1-1
- Added version-diff-build (CLI, HUB, worker)
- Improved WebUI (scans, waiver) (HUB)
- Implemented functionality for ET scans (HUB, worker)
- Fixed several bugs on worker (worker)
- Tarball on hub is now automatically extracted (worker, HUB)
- You may browse more types of log files (.out, .html, etc.) (HUB)

* Thu Dec  8 2011 Daniel Mach <dmach@redhat.com> - 0.2.0-1
- Implement a mock-build command and brew build support. (Daniel Mach)
- Minor tweaks to hub settings and client configuration. (Daniel Mach)
- Add a --timeout option to the diff-build command. (Daniel Mach)

* Tue Jun 14 2011 Daniel Mach <dmach@redhat.com> - 0.1.0-1
- Initial build.
